powered by
Returns DMRs in a nested list using echoGetEffluent(). Uses a dataframe with a column of p_id numbers. Please note that p_id's are case sensitive.
echoGetEffluent()
downloadDMRs(df, idColumn, pBar = TRUE, verbose = FALSE, ...)
dataframe df, with a column containing the discharge monitoring reports downloaded with echoGetEffluentSummary
dataframe with column of id numbers
unquoted string, name of column containing the p_id permit numbers
logical, display a progress bar? Defaults to TRUE
logical, indicating whether to provide processing and retrieval messages. Defaults to FALSE. Suggest leaving this FALSE if pBar = TRUE.
pBar = TRUE
additional arguments passed to echoGetEffluent
# \donttest{ ## This example requires an internet connection to run ## Retrieve multiple DMRs for flow df <- tibble::tibble("id" = c('TX0119407', 'TX0132187')) df <- downloadDMRs(df, id) # }
Run the code above in your browser using DataLab