| echoNNCRGetReport | R Documentation |
Returns compliance and enforcement history for one or more facilities or NPDES permits at a time, across all available quarters. Uses EPA's ECHO API: https://echo.epa.gov/tools/web-services/npdes-noncompliance-report.
echoNNCRGetReport(verbose = FALSE, ...)
verbose |
Logical, indicating whether to provide processing and retrieval messages. Defaults to FALSE. |
... |
Further arguments passed as query parameters in the request sent
to EPA ECHO's API. One of |
Returns a dataframe. Nested facility, permit, and violation-level detail returned by the service is preserved as list-columns.
## This example requires an internet connection to run
echoNNCRGetReport(permits__npdes_id = "TX0119407")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.