| echoNNCRGetSearch | R Documentation |
Returns a dataframe of permits and their summarized violation counts for a given fiscal year quarter, matching the search criteria. Uses EPA's ECHO API: https://echo.epa.gov/tools/web-services/npdes-noncompliance-report.
echoNNCRGetSearch(verbose = FALSE, ...)
verbose |
Logical, indicating whether to provide processing and retrieval messages. Defaults to FALSE. |
... |
Further arguments passed as query parameters in the request sent
to EPA ECHO's API. |
Returns a dataframe.
echoNNCRGetQuarters
## This example requires an internet connection to run
echoNNCRGetSearch(fy_quarter = "FY24Q4", permit_state = "TX")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.