| echoNNCRGetViolations | R Documentation |
Returns a dataframe of detailed violation records for a given fiscal year
quarter, optionally filtered to a single facility (frs_id) or NPDES
permit (npdes_id). Uses EPA's ECHO API:
https://echo.epa.gov/tools/web-services/npdes-noncompliance-report.
echoNNCRGetViolations(verbose = FALSE, ...)
verbose |
Logical, indicating whether to provide processing and retrieval messages. Defaults to FALSE. |
... |
Further arguments passed as query parameters in the request sent
to EPA ECHO's API. |
Returns a dataframe.
echoNNCRGetQuarters
## This example requires an internet connection to run
echoNNCRGetViolations(fy_quarter = "FY24Q4", npdes_id = "TX0119407")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.